package com.zd.laboratory.mapper;

import java.util.List;

import com.zd.laboratory.domain.vo.LiteMessageNoticeVO;
import com.zd.system.api.laboratory.domain.LabMessageUser;
import com.zd.system.api.laboratory.domain.vo.LabMessageUserListVO;
import org.apache.ibatis.annotations.Param;

/**
 * 用户消息Mapper接口
 *
 * @author zhoupan
 * @date 2021-09-02
 */
public interface LabMessageUserMapper {
    /**
     * 查询用户消息
     *
     * @param id 用户消息主键
     * @return 用户消息
     */
    public LabMessageUser selectLabMessageUserById(Long id);

    /**
     * 查询用户消息列表
     *
     * @param labMessageUser 用户消息
     * @return 用户消息集合
     */
    public List<LabMessageUser> selectLabMessageUserList(LabMessageUser labMessageUser);


    /**
     * 查询用户消息列表
     *
     * @param labMessageUser 用户消息
     * @return 用户消息集合
     */
    public List<LabMessageUser> selectLabMessageListByUser(LabMessageUser labMessageUser);

    /**
     * 查询用户消息列表VO
     *
     * @param labMessageUser 用户消息
     * @return 用户消息集合
     */
    public List<LabMessageUserListVO> selectListVO(LabMessageUser labMessageUser);

    /**
     * 查询我的消息总量
     *
     * @param userId
     * @return
     */
    public int selectMyCount(@Param("userId") Long userId,@Param("deptId") Long deptId);

    /**
     * 新增用户消息
     *
     * @param labMessageUser 用户消息
     * @return 结果
     */
    public int insertLabMessageUser(LabMessageUser labMessageUser);

    /**
     * 批量新增用户消息
     *
     * @param labMessageUser 用户消息
     * @return 结果
     */
    public int insertLabMessageUserBatch(List<LabMessageUser> labMessageUser);

    /**
     * 修改用户消息
     *
     * @param labMessageUser 用户消息
     * @return 结果
     */
    public int updateLabMessageUser(LabMessageUser labMessageUser);

    /**
     * 删除用户消息
     *
     * @param id 用户消息主键
     * @return 结果
     */
    public int deleteLabMessageUserById(Long id);

    /**
     * 批量删除用户消息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLabMessageUserByIds(Long[] ids);

    /**
     * 消息列表
     * @param id 用户ID
     * @return
     */
    List<LiteMessageNoticeVO>  queryLiteMessageNoticeVO(@Param("userId") Long userId,@Param("deptId") Long deptId);


}
